Added shift times to api.
authorFlorian Pose <fp@igh-essen.com>
Thu, 23 Apr 2009 12:20:35 +0000
changeset 1411 3ebef749275c
parent 1410 fb6719008bf5
child 1412 8f7bbbd3b7ac
Added shift times to api.
include/ecrt.h
--- a/include/ecrt.h	Thu Apr 23 12:02:26 2009 +0000
+++ b/include/ecrt.h	Thu Apr 23 12:20:35 2009 +0000
@@ -42,8 +42,9 @@
  * Changes in version 1.5:
  *
  * - Added the distributed clocks feature and the respective methods
  *   ecrt_slave_config_dc_assign_activate() and
  *   ecrt_slave_config_dc_sync_cycle_times() to configure a slave for cyclic
  *   operation, and ecrt_master_sync_reference_clock() and
  *   ecrt_master_sync_slave_clocks() for drift compensation.
  * - Changed the meaning of the negative return values of
@@ -714,6 +715,14 @@
 		uint32_t sync1_cycle_time /**< SYNC1 cycle time [ns]. */
 		);
 
+/** Sets the shift times for the SYNC0 and SYNC1 signals.
+ */
+void ecrt_slave_config_dc_sync_shift_times(
+		ec_slave_config_t *sc, /**< Slave configuration. */
+        uint32_t sync0_shift_time, /**< SYNC0 shift time [ns]. */
+		uint32_t sync1_shift_time /**< SYNC1 shift time [ns]. */
+		);
+
 /** Add an SDO configuration.
  *
  * An SDO configuration is stored in the slave configuration object and is
@@ -42,8 +42,9 @@
  *
  * - Added the distributed clocks feature and the respective methods
- *   ecrt_slave_config_dc_assign_activate() and
- *   ecrt_slave_config_dc_sync_cycle_times() to configure a slave for cyclic
+ *   ecrt_slave_config_dc_assign_activate(),
+ *   ecrt_slave_config_dc_sync_cycle_times() and
+ *   ecrt_slave_config_dc_sync_shift_times() to configure a slave for cyclic
  *   operation, and ecrt_master_sync_reference_clock() and
  *   ecrt_master_sync_slave_clocks() for drift compensation.